pub enum OracleOutcome {
Interesting,
NotInteresting,
Unresolved(UnresolvedReason),
}Expand description
Result of evaluating one candidate list.
Variants
Interesting
The candidate list still preserves the target property.
NotInteresting
The candidate list does not preserve the target property.
Unresolved(UnresolvedReason)
The oracle could not safely decide for this candidate list.